@@ -76,7 +76,7 @@ class LocalPackageDatabase:
                             f"'{mods_child}' has both a modpack.conf and a mod.conf"
                         )
                     # recursively add mods to mod2pack
-                    for submod in mods_child.iterdir():
+                    for submod in filter(lambda p: p.is_dir(), mods_child.iterdir()):
                         if (submod / "mod.conf").exists():
                             submod_conf = parse_conf_file(submod / "mod.conf")
                             submod_name = submod_conf.get("name", submod.name)
@@ -389,7 +389,7 @@ class LocalPackageDatabase:
         self._pkgs[(package.type, package.name)] = local_pkg
 
         # recursively add mods to mod2pack
-        for submod in install_path.iterdir():
+        for submod in filter(lambda p: p.is_dir(), install_path.iterdir()):
             if (submod / "mod.conf").exists():
                 submod_conf = parse_conf_file(submod / "mod.conf")
                 submod_name = submod_conf.get("name", submod.name)
